+++
title = "Date and slug inheritance (English)"
date = 2018-02-12
slug = "date-and-slug-inheritance"
tags = ["inheritance", "date", "slug"]
draft = false
+++

Date and slug inheritance is useful when you want to use the same data
and slug for multiple posts, but in different languages.

[Spanish version](/posts/es/data-and-slug-inheritance)
